pub enum CryptoStoreError {
AccountUnset,
MismatchedAccount {
expected: (OwnedUserId, OwnedDeviceId),
got: (OwnedUserId, OwnedDeviceId),
},
Io(Error),
UnpicklingError,
Pickle(PickleError),
Backup(Error),
SessionCreation(SessionCreationError),
IdentifierValidation(IdParseError),
Serialization(Error),
UnsupportedDatabaseVersion(usize, usize),
Backend(Box<dyn Error + Send + Sync>),
InvalidLockGeneration(String),
}Expand description
The crypto store’s error type.
Variants
AccountUnset
The account that owns the sessions, group sessions, and devices wasn’t found.
MismatchedAccount
The store doesn’t support multiple accounts and data from another device was discovered.
Fields
expected: (OwnedUserId, OwnedDeviceId)The expected user/device id pair.
got: (OwnedUserId, OwnedDeviceId)The user/device id pair that was loaded from the store.
Io(Error)
An IO error occurred.
UnpicklingError
Failed to decrypt an pickled object.
Pickle(PickleError)
Failed to decrypt an pickled object.
Backup(Error)
Backing up a room key has failed.
SessionCreation(SessionCreationError)
The received room key couldn’t be converted into a valid Megolm session.
IdentifierValidation(IdParseError)
A Matrix identifier failed to be validated.
Serialization(Error)
The store failed to (de)serialize a data type.
UnsupportedDatabaseVersion(usize, usize)
The database format has changed in a backwards incompatible way.
Backend(Box<dyn Error + Send + Sync>)
A problem with the underlying database backend
InvalidLockGeneration(String)
An error due to an invalid generation in a cross-process locking scheme.
Implementations