IntoCryptoStore

Trait IntoCryptoStore 

pub trait IntoCryptoStore { }
A type that can be type-erased into Arc<DynCryptoStore>.

This trait is not meant to be implemented directly outside matrix-sdk-crypto, but it is automatically implemented for everything that implements CryptoStore.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoCryptoStore for Arc<DynCryptoStore>

Source

impl<T> IntoCryptoStore for Arc<T>
where T: CryptoStore + 'static,

Implementors

Source

impl<T> IntoCryptoStore for T
where T: CryptoStore + 'static,